Struct WlShmPool

pub struct WlShmPool { /* private fields */ }
Available on crate feature wayland and Linux only.
a shared memory pool

The wl_shm_pool object encapsulates a piece of memory shared between the compositor and client. Through the wl_shm_pool object, the client can allocate shared memory wl_buffer objects. All objects created through the same pool share the same underlying mapped memory. Reusing the mapped memory avoids the setup/teardown overhead and is useful when interactively resizing a surface or for many small buffers.

This interface has no events.

Implementations



impl WlShmPool

pub fn create_buffer<U, D>( &self, offset: i32, width: i32, height: i32, stride: i32, format: Format, qh: &QueueHandle<D>, udata: U, ) -> WlBuffer
where U: Send + Sync + 'static, D: Dispatch<WlBuffer, U> + 'static,

create a buffer from the pool

Create a wl_buffer object from the pool.

The buffer is created offset bytes into the pool and has width and height as specified. The stride argument specifies the number of bytes from the beginning of one row to the beginning of the next. The format is the pixel format of the buffer and must be one of those advertised through the wl_shm.format event.

A buffer will keep a reference to the pool it was created from so it is valid to destroy the pool immediately after creating a buffer from it.

pub fn destroy(&self)

destroy the pool

Destroy the shared memory pool.

The mmapped memory will be released when all buffers that have been created from this pool are gone.

pub fn resize(&self, size: i32)

change the size of the pool mapping

This request will cause the server to remap the backing memory for the pool from the file descriptor passed when the pool was created, but using the new size. This request can only be used to make the pool bigger.

This request only changes the amount of bytes that are mmapped by the server and does not touch the file corresponding to the file descriptor passed at creation time. It is the client’s responsibility to ensure that the file is at least as big as the new pool size.